# Laboratory

Management of a group of people and their publications is made with the {class}`~gismap.lab.lab.Lab` abstract class.


```{eval-rst}
.. automodule:: gismap.lab.lab
    :members:
```

## Collaboration graph

```{eval-rst}
.. automodule:: gismap.lab.graph
    :members:
```


## LIP6

```{eval-rst}
.. automodule:: gismap.lab.lip6
    :members:
```

## Toulouse

```{eval-rst}
.. automodule:: gismap.lab.toulouse
    :members:
```

## Vis

```{eval-rst}
.. automodule:: gismap.lab.vis
    :members:
```

## Expansion

```{eval-rst}
.. automodule:: gismap.lab.expansion
    :members:
```
